[libchamplainmm] Rename libchamplainmm to champlainmm



commit 7b9eef1881f292462b1c23c384930c9933785309
Author: Juan R. GarcĂ­a Blanco <juanrgar gmail com>
Date:   Sun Mar 2 10:04:54 2014 +0100

    Rename libchamplainmm to champlainmm
    
    To better match the libchamplain naming convention, libchamplainmm
    becomes now champlainmm. The project and the library remain as
    libchamplainmm, as in the case of libchamplian; but internal
    structure moves to champlainmm prefixes, e.g. headers are now
    installed in champlainmm/.

 .gitignore                                         |    2 +-
 Makefile.am                                        |   14 +++++-----
 champlain/champlainmm-uninstalled.pc.in            |   10 +++++++
 .../libchamplainmm.h => champlain/champlainmm.h    |    0
 champlain/champlainmm.pc.in                        |   19 ++++++++++++++
 .../champlainmm}/.gitignore                        |   11 +++-----
 .../champlainmm}/Makefile.am                       |   14 +++++-----
 .../champlainmm}/filelist.am                       |    0
 .../champlainmm}/wrap_init.h                       |    0
 .../champlainmmconfig.h.in                         |    6 ++--
 {libchamplain => champlain}/src/Makefile.am        |    4 +-
 champlain/src/champlain.defs                       |    5 ++++
 .../src/champlain_docs.xml                         |    0
 .../src/champlain_docs_override.xml                |    0
 .../src/champlain_enums.defs                       |    0
 .../src/champlain_extra.defs                       |    0
 .../src/champlain_methods.defs                     |    0
 .../src/champlain_signals.defs                     |    0
 {libchamplain => champlain}/src/defines.ccg        |    0
 {libchamplain => champlain}/src/defines.hg         |    2 +-
 {libchamplain => champlain}/src/filelist.am        |   14 +++++-----
 {libchamplain => champlain}/src/label.ccg          |    0
 {libchamplain => champlain}/src/label.hg           |    6 ++--
 {libchamplain => champlain}/src/layer.ccg          |    0
 {libchamplain => champlain}/src/layer.hg           |    2 +-
 .../src/map-source-desc.ccg                        |    0
 {libchamplain => champlain}/src/map-source-desc.hg |    4 +-
 .../src/map-source-factory.ccg                     |    0
 .../src/map-source-factory.hg                      |    8 +++---
 {libchamplain => champlain}/src/map-source.ccg     |    0
 {libchamplain => champlain}/src/map-source.hg      |    4 +-
 {libchamplain => champlain}/src/map.hg             |    4 +-
 {libchamplain => champlain}/src/marker-layer.ccg   |    0
 {libchamplain => champlain}/src/marker-layer.hg    |    8 +++---
 {libchamplain => champlain}/src/marker.ccg         |    0
 {libchamplain => champlain}/src/marker.hg          |    2 +-
 {libchamplain => champlain}/src/path-layer.ccg     |    0
 {libchamplain => champlain}/src/path-layer.hg      |    4 +-
 {libchamplain => champlain}/src/point.ccg          |    0
 {libchamplain => champlain}/src/point.hg           |    6 ++--
 {libchamplain => champlain}/src/tile.ccg           |    0
 {libchamplain => champlain}/src/tile.hg            |    4 +-
 {libchamplain => champlain}/src/view.ccg           |    0
 {libchamplain => champlain}/src/view.hg            |   26 +++----------------
 configure.ac                                       |   22 ++++++++--------
 libchamplain/libchamplainmm-uninstalled.pc.in      |   10 -------
 libchamplain/libchamplainmm.pc.in                  |   19 --------------
 libchamplain/src/libchamplain.defs                 |    5 ----
 tools/Makefile.am                                  |    6 ++--
 tools/gen_scripts/champlain_generate_docs.sh       |    8 +++---
 tools/gen_scripts/champlain_generate_enums.sh      |    4 +-
 tools/gen_scripts/champlain_generate_extra_defs.sh |   22 ++++++++--------
 tools/gen_scripts/champlain_generate_methods.sh    |    4 +-
 53 files changed, 129 insertions(+), 150 deletions(-)
---
diff --git a/.gitignore b/.gitignore
index 7621182..5a11c5a 100644
--- a/.gitignore
+++ b/.gitignore
@@ -9,7 +9,7 @@ configure
 depcomp
 generate_extra_defs
 install-sh
-libchamplainmmconfig.h
+champlainmmconfig.h
 libtool
 ltmain.sh
 missing
diff --git a/Makefile.am b/Makefile.am
index 573400e..5ba53b9 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -19,20 +19,20 @@ ACLOCAL_AMFLAGS = -I build ${ACLOCAL_FLAGS}
 DISTCHECK_CONFIGURE_FLAGS = --enable-warnings=fatal
 
 if MAINTAINER_MODE
-src_subdirs = tools libchamplain/src
+src_subdirs = tools champlain/src
 else
 src_subdirs =
 endif
-SUBDIRS = $(src_subdirs) libchamplain/libchamplainmm
+SUBDIRS = $(src_subdirs) champlain/champlainmm
 
-libchamplainmm_includedir = $(includedir)/$(LIBCHAMPLAINMM_MODULE_NAME)
-libchamplainmm_include_HEADERS = libchamplain/libchamplainmm.h
+champlainmm_includedir = $(includedir)/$(CHAMPLAINMM_MODULE_NAME)
+champlainmm_include_HEADERS = champlain/champlainmm.h
 
-libchamplainmm_libincludedir = $(libdir)/$(LIBCHAMPLAINMM_MODULE_NAME)/include
-nodist_libchamplainmm_libinclude_HEADERS = libchamplain/libchamplainmmconfig.h
+champlainmm_libincludedir = $(libdir)/$(CHAMPLAINMM_MODULE_NAME)/include
+nodist_champlainmm_libinclude_HEADERS = champlain/champlainmmconfig.h
 
 pkgconfigdir = $(libdir)/pkgconfig
-pkgconfig_DATA = libchamplain/$(LIBCHAMPLAINMM_MODULE_NAME).pc
+pkgconfig_DATA = champlain/$(CHAMPLAINMM_MODULE_NAME).pc
 
 dist_noinst_SCRIPTS = autogen.sh
 
diff --git a/champlain/champlainmm-uninstalled.pc.in b/champlain/champlainmm-uninstalled.pc.in
new file mode 100644
index 0000000..841d6cf
--- /dev/null
+++ b/champlain/champlainmm-uninstalled.pc.in
@@ -0,0 +1,10 @@
+doxytagfile=${pc_top_builddir}/doc/reference/@CHAMPLAINMM_MODULE_NAME  tag
+htmlrefpub=http://library.gnome.org/@PACKAGE_TARNAME@/unstable/
+
+Name: libchamplainmm
+Description: C++ bindings for libchamplain, not installed
+Version: @CHAMPLAINMM_VERSION@
+URL: http://www.gtkmm.org/
+Requires: @CHAMPLAINMM_MODULES@
+Libs: ${pc_top_builddir}/${pcfiledir}/champlainmm/champlainmm- CHAMPLAINMM_API_VERSION@.la
+Cflags: -I${pc_top_builddir}/${pcfiledir} -I${pc_top_builddir}/${pcfiledir}/@srcdir@
diff --git a/libchamplain/libchamplainmm.h b/champlain/champlainmm.h
similarity index 100%
rename from libchamplain/libchamplainmm.h
rename to champlain/champlainmm.h
diff --git a/champlain/champlainmm.pc.in b/champlain/champlainmm.pc.in
new file mode 100644
index 0000000..d03a269
--- /dev/null
+++ b/champlain/champlainmm.pc.in
@@ -0,0 +1,19 @@
+prefix= prefix@
+exec_prefix= exec_prefix@
+libdir= libdir@
+datarootdir= datarootdir@
+datadir= datadir@
+includedir= includedir@
+
+docdir=${datarootdir}/doc/@CHAMPLAINMM_MODULE_NAME@
+doxytagfile=${docdir}/reference/@CHAMPLAINMM_MODULE_NAME  tag
+htmlrefdir=${docdir}/reference/html
+htmlrefpub=http://library.gnome.org/@PACKAGE_TARNAME@/unstable/
+
+Name: libchamplainmm
+Description: C++ bindings for libchamplain
+Version: @CHAMPLAINMM_VERSION@
+URL: http://www.gtkmm.org/
+Requires: @CHAMPLAINMM_MODULES@
+Libs: -L${libdir} -lchamplainmm- CHAMPLAINMM_API_VERSION@
+Cflags: -I${includedir}/@CHAMPLAINMM_MODULE_NAME@ -I${libdir}/@CHAMPLAINMM_MODULE_NAME@/include
diff --git a/libchamplain/libchamplainmm/.gitignore b/champlain/champlainmm/.gitignore
similarity index 59%
rename from libchamplain/libchamplainmm/.gitignore
rename to champlain/champlainmm/.gitignore
index 731d492..e720592 100644
--- a/libchamplain/libchamplainmm/.gitignore
+++ b/champlain/champlainmm/.gitignore
@@ -1,17 +1,14 @@
-base-marker.*
-cache.*
 defines.*
+label.*
 layer.*
 map-source-desc.*
 map-source-factory.*
 map-source.*
+marker-layer.*
 marker.*
-network-map-source.*
+path-layer.*
 point.*
-polygon.*
-private
-selection-layer.*
 tile.*
 view.*
 wrap_init.cc
-zoom-level.*
+private
diff --git a/libchamplain/libchamplainmm/Makefile.am b/champlain/champlainmm/Makefile.am
similarity index 62%
rename from libchamplain/libchamplainmm/Makefile.am
rename to champlain/champlainmm/Makefile.am
index 60e1424..b2f5042 100644
--- a/libchamplain/libchamplainmm/Makefile.am
+++ b/champlain/champlainmm/Makefile.am
@@ -15,17 +15,17 @@
 ## You should have received a copy of the GNU Lesser General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-lib_LTLIBRARIES = libchamplainmm- LIBCHAMPLAINMM_API_VERSION@.la
+lib_LTLIBRARIES = libchamplainmm- CHAMPLAINMM_API_VERSION@.la
 
 include $(srcdir)/../src/filelist.am
 include $(srcdir)/filelist.am
 include $(top_srcdir)/build/compile-binding.am
 
-local_cppflags = $(binding_includes) $(binding_cppflags) -DLIBCHAMPLAINMM_BUILD=1
+local_cppflags = $(binding_includes) $(binding_cppflags) -DCHAMPLAINMM_BUILD=1
 
-AM_CPPFLAGS = $(local_cppflags) $(GTHREAD_CFLAGS) $(LIBCHAMPLAINMM_CFLAGS)
-AM_CXXFLAGS = $(LIBCHAMPLAINMM_WXXFLAGS)
+AM_CPPFLAGS = $(local_cppflags) $(GTHREAD_CFLAGS) $(CHAMPLAINMM_CFLAGS)
+AM_CXXFLAGS = $(CHAMPLAINMM_WXXFLAGS)
 
-libchamplainmm_ LIBCHAMPLAINMM_API_VERSION@_la_SOURCES = $(binding_sources)
-libchamplainmm_ LIBCHAMPLAINMM_API_VERSION@_la_LDFLAGS = -no-undefined -version-info 
$(LIBCHAMPLAINMM_SO_VERSION)
-libchamplainmm_ LIBCHAMPLAINMM_API_VERSION@_la_LIBADD  = $(LIBCHAMPLAINMM_LIBS)
+libchamplainmm_ CHAMPLAINMM_API_VERSION@_la_SOURCES = $(binding_sources)
+libchamplainmm_ CHAMPLAINMM_API_VERSION@_la_LDFLAGS = -no-undefined -version-info $(CHAMPLAINMM_SO_VERSION)
+libchamplainmm_ CHAMPLAINMM_API_VERSION@_la_LIBADD  = $(CHAMPLAINMM_LIBS)
diff --git a/libchamplain/libchamplainmm/filelist.am b/champlain/champlainmm/filelist.am
similarity index 100%
rename from libchamplain/libchamplainmm/filelist.am
rename to champlain/champlainmm/filelist.am
diff --git a/libchamplain/libchamplainmm/wrap_init.h b/champlain/champlainmm/wrap_init.h
similarity index 100%
rename from libchamplain/libchamplainmm/wrap_init.h
rename to champlain/champlainmm/wrap_init.h
diff --git a/libchamplain/libchamplainmmconfig.h.in b/champlain/champlainmmconfig.h.in
similarity index 63%
rename from libchamplain/libchamplainmmconfig.h.in
rename to champlain/champlainmmconfig.h.in
index 46ac6e9..7916673 100644
--- a/libchamplain/libchamplainmmconfig.h.in
+++ b/champlain/champlainmmconfig.h.in
@@ -1,10 +1,10 @@
 /* This file is part of libchamplainmm. */
 
 /* Major version number of libchamplainmm. */
-#undef LIBCHAMPLAINMM_MAJOR_VERSION
+#undef CHAMPLAINMM_MAJOR_VERSION
 
 /* Micro version number of libchamplainmm. */
-#undef LIBCHAMPLAINMM_MICRO_VERSION
+#undef CHAMPLAINMM_MICRO_VERSION
 
 /* Minor version number of libchamplainmm. */
-#undef LIBCHAMPLAINMM_MINOR_VERSION
+#undef CHAMPLAINMM_MINOR_VERSION
diff --git a/libchamplain/src/Makefile.am b/champlain/src/Makefile.am
similarity index 90%
rename from libchamplain/src/Makefile.am
rename to champlain/src/Makefile.am
index 61b59a5..359ee98 100644
--- a/libchamplain/src/Makefile.am
+++ b/champlain/src/Makefile.am
@@ -15,8 +15,8 @@
 ## You should have received a copy of the GNU Lesser General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-binding_name    = libchamplainmm
-wrap_init_flags = --namespace=Champlain --parent_dir=libchamplainmm
+binding_name    = champlainmm
+wrap_init_flags = --namespace=Champlain --parent_dir=champlainmm
 codegen_srcdir  = $(top_srcdir)/tools
 
 include $(srcdir)/filelist.am
diff --git a/champlain/src/champlain.defs b/champlain/src/champlain.defs
new file mode 100644
index 0000000..68784da
--- /dev/null
+++ b/champlain/src/champlain.defs
@@ -0,0 +1,5 @@
+;; Include generated API definition files
+(include champlain_enums.defs)
+(include champlain_extra.defs)
+(include champlain_methods.defs)
+(include champlain_signals.defs)
diff --git a/libchamplain/src/libchamplain_docs.xml b/champlain/src/champlain_docs.xml
similarity index 100%
rename from libchamplain/src/libchamplain_docs.xml
rename to champlain/src/champlain_docs.xml
diff --git a/libchamplain/src/libchamplain_docs_override.xml b/champlain/src/champlain_docs_override.xml
similarity index 100%
rename from libchamplain/src/libchamplain_docs_override.xml
rename to champlain/src/champlain_docs_override.xml
diff --git a/libchamplain/src/libchamplain_enums.defs b/champlain/src/champlain_enums.defs
similarity index 100%
rename from libchamplain/src/libchamplain_enums.defs
rename to champlain/src/champlain_enums.defs
diff --git a/libchamplain/src/libchamplain_extra.defs b/champlain/src/champlain_extra.defs
similarity index 100%
rename from libchamplain/src/libchamplain_extra.defs
rename to champlain/src/champlain_extra.defs
diff --git a/libchamplain/src/libchamplain_methods.defs b/champlain/src/champlain_methods.defs
similarity index 100%
rename from libchamplain/src/libchamplain_methods.defs
rename to champlain/src/champlain_methods.defs
diff --git a/libchamplain/src/libchamplain_signals.defs b/champlain/src/champlain_signals.defs
similarity index 100%
rename from libchamplain/src/libchamplain_signals.defs
rename to champlain/src/champlain_signals.defs
diff --git a/libchamplain/src/defines.ccg b/champlain/src/defines.ccg
similarity index 100%
rename from libchamplain/src/defines.ccg
rename to champlain/src/defines.ccg
diff --git a/libchamplain/src/defines.hg b/champlain/src/defines.hg
similarity index 96%
rename from libchamplain/src/defines.hg
rename to champlain/src/defines.hg
index 59f1a10..1024b10 100644
--- a/libchamplain/src/defines.hg
+++ b/champlain/src/defines.hg
@@ -16,7 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 namespace Champlain
 {
diff --git a/libchamplain/src/filelist.am b/champlain/src/filelist.am
similarity index 62%
rename from libchamplain/src/filelist.am
rename to champlain/src/filelist.am
index 80e5279..fc9e546 100644
--- a/libchamplain/src/filelist.am
+++ b/champlain/src/filelist.am
@@ -1,13 +1,13 @@
 ## This file is part of libchamplainmm.
 
 files_defs =                                   \
-       libchamplain.defs                       \
-       libchamplain_enums.defs                 \
-       libchamplain_extra.defs                 \
-       libchamplain_methods.defs               \
-       libchamplain_signals.defs               \
-       libchamplain_docs.xml                   \
-       libchamplain_docs_override.xml
+       champlain.defs                  \
+       champlain_enums.defs                    \
+       champlain_extra.defs                    \
+       champlain_methods.defs          \
+       champlain_signals.defs          \
+       champlain_docs.xml                      \
+       champlain_docs_override.xml
 
 files_hg  =                                    \
        marker.hg                               \
diff --git a/libchamplain/src/label.ccg b/champlain/src/label.ccg
similarity index 100%
rename from libchamplain/src/label.ccg
rename to champlain/src/label.ccg
diff --git a/libchamplain/src/label.hg b/champlain/src/label.hg
similarity index 98%
rename from libchamplain/src/label.hg
rename to champlain/src/label.hg
index 8f95033..0d08a85 100644
--- a/libchamplain/src/label.hg
+++ b/champlain/src/label.hg
@@ -16,15 +16,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libchamplainmm/marker.h>
+#include <champlainmm/marker.h>
 #include <cluttermm/color.h>
 #include <cluttermm/actor.h>
 #include <pangomm/layout.h>
 #include <pangomm/attrlist.h>
 #include <string>
 
-_DEFS(libchamplainmm,libchamplain)
-_PINCLUDE(libchamplainmm/private/marker_p.h)
+_DEFS(champlainmm,champlain)
+_PINCLUDE(champlainmm/private/marker_p.h)
 
 namespace Champlain
 {
diff --git a/libchamplain/src/layer.ccg b/champlain/src/layer.ccg
similarity index 100%
rename from libchamplain/src/layer.ccg
rename to champlain/src/layer.ccg
diff --git a/libchamplain/src/layer.hg b/champlain/src/layer.hg
similarity index 97%
rename from libchamplain/src/layer.hg
rename to champlain/src/layer.hg
index da4a877..63da71e 100644
--- a/libchamplain/src/layer.hg
+++ b/champlain/src/layer.hg
@@ -18,7 +18,7 @@
 
 #include <cluttermm.h>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 _CC_INCLUDE(champlain/champlain.h)
 _PINCLUDE(cluttermm/private/group_p.h)
diff --git a/libchamplain/src/map-source-desc.ccg b/champlain/src/map-source-desc.ccg
similarity index 100%
rename from libchamplain/src/map-source-desc.ccg
rename to champlain/src/map-source-desc.ccg
diff --git a/libchamplain/src/map-source-desc.hg b/champlain/src/map-source-desc.hg
similarity index 96%
rename from libchamplain/src/map-source-desc.hg
rename to champlain/src/map-source-desc.hg
index 4049066..bb91496 100644
--- a/libchamplain/src/map-source-desc.hg
+++ b/champlain/src/map-source-desc.hg
@@ -20,8 +20,8 @@
 
 #include <glibmm/object.h>
 #include <champlain/champlain.h>
-#include <libchamplainmm/map-source.h>
-_DEFS(libchamplainmm,libchamplain)
+#include <champlainmm/map-source.h>
+_DEFS(champlainmm,champlain)
 _PINCLUDE(glibmm/private/object_p.h)
 
 namespace Champlain
diff --git a/libchamplain/src/map-source-factory.ccg b/champlain/src/map-source-factory.ccg
similarity index 100%
rename from libchamplain/src/map-source-factory.ccg
rename to champlain/src/map-source-factory.ccg
diff --git a/libchamplain/src/map-source-factory.hg b/champlain/src/map-source-factory.hg
similarity index 91%
rename from libchamplain/src/map-source-factory.hg
rename to champlain/src/map-source-factory.hg
index 1333b34..23240cb 100644
--- a/libchamplain/src/map-source-factory.hg
+++ b/champlain/src/map-source-factory.hg
@@ -20,11 +20,11 @@
 #include <glibmm.h>
 #include <sigc++/sigc++.h>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
-#include<champlain/champlain.h>
-#include<libchamplainmm/map-source-desc.h>
-#include<libchamplainmm/map-source.h>
+#include <champlain/champlain.h>
+#include <champlainmm/map-source-desc.h>
+#include <champlainmm/map-source.h>
 _PINCLUDE(glibmm/private/object_p.h)
 
 namespace Champlain
diff --git a/libchamplain/src/map-source.ccg b/champlain/src/map-source.ccg
similarity index 100%
rename from libchamplain/src/map-source.ccg
rename to champlain/src/map-source.ccg
diff --git a/libchamplain/src/map-source.hg b/champlain/src/map-source.hg
similarity index 97%
rename from libchamplain/src/map-source.hg
rename to champlain/src/map-source.hg
index 7a01778..0d4e121 100644
--- a/libchamplain/src/map-source.hg
+++ b/champlain/src/map-source.hg
@@ -19,10 +19,10 @@
 #include <string>
 #include <glibmm.h>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 _CC_INCLUDE(champlain/champlain.h)
-_CC_INCLUDE(libchamplainmm/tile.h)
+_CC_INCLUDE(champlainmm/tile.h)
 _PINCLUDE(glibmm/private/object_p.h)
 _PINCLUDE(champlain/champlain.h)
 
diff --git a/libchamplain/src/map.hg b/champlain/src/map.hg
similarity index 92%
rename from libchamplain/src/map.hg
rename to champlain/src/map.hg
index 148fdd5..f2a3669 100644
--- a/libchamplain/src/map.hg
+++ b/champlain/src/map.hg
@@ -16,9 +16,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libchamplainmm/zoom-level.h>
+#include <champlainmm/zoom-level.h>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 namespace Champlain
 {
diff --git a/libchamplain/src/marker-layer.ccg b/champlain/src/marker-layer.ccg
similarity index 100%
rename from libchamplain/src/marker-layer.ccg
rename to champlain/src/marker-layer.ccg
diff --git a/libchamplain/src/marker-layer.hg b/champlain/src/marker-layer.hg
similarity index 94%
rename from libchamplain/src/marker-layer.hg
rename to champlain/src/marker-layer.hg
index 9223107..f886e71 100644
--- a/libchamplain/src/marker-layer.hg
+++ b/champlain/src/marker-layer.hg
@@ -17,14 +17,14 @@
  */
 
 #include <glibmm.h>
-#include <libchamplainmm/layer.h>
-#include <libchamplainmm/marker.h>
+#include <champlainmm/layer.h>
+#include <champlainmm/marker.h>
 #include <vector>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 _CC_INCLUDE(champlain/champlain.h)
-_PINCLUDE(libchamplainmm/private/layer_p.h)
+_PINCLUDE(champlainmm/private/layer_p.h)
 
 namespace Champlain
 {
diff --git a/libchamplain/src/marker.ccg b/champlain/src/marker.ccg
similarity index 100%
rename from libchamplain/src/marker.ccg
rename to champlain/src/marker.ccg
diff --git a/libchamplain/src/marker.hg b/champlain/src/marker.hg
similarity index 98%
rename from libchamplain/src/marker.hg
rename to champlain/src/marker.hg
index 15df65a..6481f71 100644
--- a/libchamplain/src/marker.hg
+++ b/champlain/src/marker.hg
@@ -18,7 +18,7 @@
 
 #include <cluttermm.h>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 _CC_INCLUDE(champlain/champlain.h)
 _PINCLUDE(cluttermm/private/actor_p.h)
diff --git a/libchamplain/src/path-layer.ccg b/champlain/src/path-layer.ccg
similarity index 100%
rename from libchamplain/src/path-layer.ccg
rename to champlain/src/path-layer.ccg
diff --git a/libchamplain/src/path-layer.hg b/champlain/src/path-layer.hg
similarity index 97%
rename from libchamplain/src/path-layer.hg
rename to champlain/src/path-layer.hg
index 2f4254c..c60742e 100644
--- a/libchamplain/src/path-layer.hg
+++ b/champlain/src/path-layer.hg
@@ -18,8 +18,8 @@
 
 #include <cluttermm.h>
 #include <glibmm.h>
-#include <libchamplainmm/point.h>
-_DEFS(libchamplainmm,libchamplain)
+#include <champlainmm/point.h>
+_DEFS(champlainmm,champlain)
 _PINCLUDE(glibmm/private/object_p.h)
 
 namespace Champlain
diff --git a/libchamplain/src/point.ccg b/champlain/src/point.ccg
similarity index 100%
rename from libchamplain/src/point.ccg
rename to champlain/src/point.ccg
diff --git a/libchamplain/src/point.hg b/champlain/src/point.hg
similarity index 91%
rename from libchamplain/src/point.hg
rename to champlain/src/point.hg
index 5b9f9b8..21d5fe1 100644
--- a/libchamplain/src/point.hg
+++ b/champlain/src/point.hg
@@ -16,9 +16,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libchamplainmm/marker.h>
-_DEFS(libchamplainmm,libchamplain)
-_PINCLUDE(libchamplainmm/private/marker_p.h)
+#include <champlainmm/marker.h>
+_DEFS(champlainmm,champlain)
+_PINCLUDE(champlainmm/private/marker_p.h)
 
 namespace Champlain
 {
diff --git a/libchamplain/src/tile.ccg b/champlain/src/tile.ccg
similarity index 100%
rename from libchamplain/src/tile.ccg
rename to champlain/src/tile.ccg
diff --git a/libchamplain/src/tile.hg b/champlain/src/tile.hg
similarity index 98%
rename from libchamplain/src/tile.hg
rename to champlain/src/tile.hg
index d3ef299..05170c6 100644
--- a/libchamplain/src/tile.hg
+++ b/champlain/src/tile.hg
@@ -18,9 +18,9 @@
 
 #include <string>
 #include <cluttermm.h>
-#include <libchamplainmm/defines.h>
+#include <champlainmm/defines.h>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 _CC_INCLUDE(champlain/champlain.h)
 _PINCLUDE(glibmm/private/object_p.h)
diff --git a/libchamplain/src/view.ccg b/champlain/src/view.ccg
similarity index 100%
rename from libchamplain/src/view.ccg
rename to champlain/src/view.ccg
diff --git a/libchamplain/src/view.hg b/champlain/src/view.hg
similarity index 83%
rename from libchamplain/src/view.hg
rename to champlain/src/view.hg
index 11c74be..e83e87c 100644
--- a/libchamplain/src/view.hg
+++ b/champlain/src/view.hg
@@ -17,24 +17,20 @@
  */
 
 #include <cluttermm.h>
-#include <libchamplainmm/tile.h>
+#include <champlainmm/tile.h>
 
-_DEFS(libchamplainmm,libchamplain)
+_DEFS(champlainmm,champlain)
 
 _CC_INCLUDE(champlain/champlain.h)
-_CC_INCLUDE(libchamplainmm/base-marker.h)
-_CC_INCLUDE(libchamplainmm/layer.h)
-_CC_INCLUDE(libchamplainmm/map-source.h)
-_CC_INCLUDE(libchamplainmm/polygon.h)
+_CC_INCLUDE(champlainmm/layer.h)
+_CC_INCLUDE(champlainmm/map-source.h)
 _PINCLUDE(cluttermm/private/group_p.h)
 
 namespace Champlain
 {
 
-class BaseMarker;
 class Layer;
 class MapSource;
-class Polygon;
 
 class View :
     public Clutter::Group
@@ -83,16 +79,6 @@ public:
   _WRAP_METHOD(void set_min_zoom_level(guint zoom_level),
                champlain_view_set_min_zoom_level)
 
-//  _WRAP_METHOD(void ensure_visible(double lat1, double lon1,
-//                                   double lat2, double lon2,
-//                                   bool animate),
-//               champlain_view_ensure_visible)
-  _WRAP_METHOD(
-      void ensure_markers_visible(
-          const Glib::ArrayHandle<Glib::RefPtr<BaseMarker> > & markers,
-          bool animate),
-      champlain_view_ensure_markers_visible)
-
   _WRAP_METHOD(void set_map_source(const Glib::RefPtr<MapSource> & map_source),
                champlain_view_set_map_source)
   _WRAP_METHOD(void set_size(guint width, guint height),
@@ -108,12 +94,8 @@ public:
 
   _WRAP_METHOD(void add_layer(const Glib::RefPtr<Layer> & layer),
                champlain_view_add_layer)
-  _WRAP_METHOD(void add_polygon(const Glib::RefPtr<Polygon> & polygon),
-               champlain_view_add_polygon)
   _WRAP_METHOD(void remove_layer(const Glib::RefPtr<Layer> & layer),
                champlain_view_remove_layer)
-  _WRAP_METHOD(void remove_polygon(const Glib::RefPtr<Polygon> & polygon),
-               champlain_view_remove_polygon)
 
   _WRAP_METHOD(void get_coords_at(guint x, guint y,
                                   double & latitude,
diff --git a/configure.ac b/configure.ac
index 285a478..88021bd 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,10 +18,10 @@
 AC_INIT([libchamplainmm], [0.12.0], [http://bugzilla.gnome.org/], [libchamplainmm], [http://www.gtkmm.org/])
 AC_PREREQ([2.59])
 
-AC_CONFIG_SRCDIR([libchamplain/libchamplainmm.h])
+AC_CONFIG_SRCDIR([champlain/champlainmm.h])
 AC_CONFIG_AUX_DIR([build])
 AC_CONFIG_MACRO_DIR([build])
-AC_CONFIG_HEADERS([build/config.h libchamplain/libchamplainmmconfig.h])
+AC_CONFIG_HEADERS([build/config.h champlain/champlainmmconfig.h])
 
 AM_INIT_AUTOMAKE([1.9 -Wno-portability check-news dist-bzip2 no-define nostdinc tar-ustar])
 m4_ifdef([AM_SILENT_RULES], [AM_SILENT_RULES])
@@ -29,18 +29,18 @@ AM_MAINTAINER_MODE
 AC_ARG_VAR([ACLOCAL_FLAGS], [aclocal flags, e.g. -I <macro dir>])
 
 MM_PREREQ([0.8])
-MM_INIT_MODULE([libchamplainmm-1.0])
+MM_INIT_MODULE([champlainmm-0.12])
 
 # http://www.gnu.org/software/libtool/manual/html_node/Updating-version-info.html
-AC_SUBST([LIBCHAMPLAINMM_SO_VERSION], [1:0:0])
+AC_SUBST([CHAMPLAINMM_SO_VERSION], [1:0:0])
 
 AC_PROG_CXX
 AC_DISABLE_STATIC
 AC_LIBTOOL_WIN32_DLL
 AC_PROG_LIBTOOL
 
-AC_SUBST([LIBCHAMPLAINMM_MODULES], ['champlain-0.12 cluttermm-1.0 glibmm-2.4 >= 2.16'])
-PKG_CHECK_MODULES([LIBCHAMPLAINMM], [$LIBCHAMPLAINMM_MODULES])
+AC_SUBST([CHAMPLAINMM_MODULES], ['champlain-0.12 cluttermm-1.0 glibmm-2.4 >= 2.16'])
+PKG_CHECK_MODULES([CHAMPLAINMM], [$CHAMPLAINMM_MODULES])
 
 MM_PKG_CONFIG_SUBST([GTHREAD_CFLAGS], [--cflags-only-other gthread-2.0])
 MM_PKG_CONFIG_SUBST([GMMPROC_DIR], [--variable=gmmprocdir glibmm-2.4])
@@ -52,15 +52,15 @@ MM_ARG_WITH_TAGFILE_DOC([libsigc++-2.0.tag], [sigc++-2.0])
 MM_ARG_WITH_TAGFILE_DOC([glibmm-2.4.tag], [glibmm-2.4])
 
 AC_LANG([C++])
-MM_ARG_ENABLE_WARNINGS([LIBCHAMPLAINMM_WXXFLAGS],
+MM_ARG_ENABLE_WARNINGS([CHAMPLAINMM_WXXFLAGS],
                        [-Wall],
                        [-pedantic -Wall -Wextra],
                        [G LIBCHAMPLAIN])
 
 AC_CONFIG_FILES([Makefile
                  tools/Makefile
-                 libchamplain/${LIBCHAMPLAINMM_MODULE_NAME}.pc:libchamplain/libchamplainmm.pc.in
-                 
libchamplain/${LIBCHAMPLAINMM_MODULE_NAME}-uninstalled.pc:libchamplain/libchamplainmm-uninstalled.pc.in
-                 libchamplain/src/Makefile
-                 libchamplain/libchamplainmm/Makefile])
+                 champlain/${CHAMPLAINMM_MODULE_NAME}.pc:champlain/champlainmm.pc.in
+                 champlain/${CHAMPLAINMM_MODULE_NAME}-uninstalled.pc:champlain/champlainmm-uninstalled.pc.in
+                 champlain/src/Makefile
+                 champlain/champlainmm/Makefile])
 AC_OUTPUT
diff --git a/tools/Makefile.am b/tools/Makefile.am
index c5de309..0c7bdfe 100644
--- a/tools/Makefile.am
+++ b/tools/Makefile.am
@@ -23,10 +23,10 @@ dist_noinst_DATA = $(addprefix m4/,$(files_codegen_m4))
 noinst_PROGRAMS  = extradefs/generate_extra_defs
 
 extradefs_generate_extra_defs_SOURCES = extradefs/generate_extra_defs_libchamplain.cc
-extradefs_generate_extra_defs_LDADD   = $(LIBCHAMPLAINMM_LIBS) -lglibmm_generate_extra_defs-2.4
+extradefs_generate_extra_defs_LDADD   = $(CHAMPLAINMM_LIBS) -lglibmm_generate_extra_defs-2.4
 
-AM_CPPFLAGS = -I$(top_builddir) $(GTHREAD_CFLAGS) $(LIBCHAMPLAINMM_CFLAGS)
-AM_CXXFLAGS = $(LIBCHAMPLAINMM_WXXFLAGS)
+AM_CPPFLAGS = -I$(top_builddir) $(GTHREAD_CFLAGS) $(CHAMPLAINMM_CFLAGS)
+AM_CXXFLAGS = $(CHAMPLAINMM_WXXFLAGS)
 
 # Instruct GNU make to delete the targets of a rule after it failed, in
 # order to avoid the complication of handling that situation manually.
diff --git a/tools/gen_scripts/champlain_generate_docs.sh b/tools/gen_scripts/champlain_generate_docs.sh
index 5578bf3..658ce03 100755
--- a/tools/gen_scripts/champlain_generate_docs.sh
+++ b/tools/gen_scripts/champlain_generate_docs.sh
@@ -2,7 +2,7 @@
 
 # Note that JHBUILD_SOURCES should be defined to contain the path to the root
 # of the jhbuild sources. The script assumes that it resides in the
-# tools/gen_scripts/ directory and the XML file will be placed in libchamplain/src.
+# tools/gen_scripts/ directory and the XML file will be placed in champlain/src.
 
 if [ -z "$JHBUILD_SOURCES" ]; then
   echo -e "JHBUILD_SOURCES must contain the path to the jhbuild sources."
@@ -10,11 +10,11 @@ if [ -z "$JHBUILD_SOURCES" ]; then
 fi
 
 ROOT_DIR="$(dirname "$0")/../.."
-OUT_DIR="$ROOT_DIR/libchamplain/src"
+OUT_DIR="$ROOT_DIR/champlain/src"
 
-for dir in "$JHBUILD_SOURCES"/libchamplain/champlain; do
+for dir in "$JHBUILD_SOURCES"/champlain/champlain; do
   PARAMS="$PARAMS -s $dir"
 done
 
 DOCEXTRACT_TO_XML_PY="$JHBUILD_SOURCES/glibmm/tools/defs_gen/docextract_to_xml.py"
-$DOCEXTRACT_TO_XML_PY $PARAMS > "$OUT_DIR/libchamplain_docs.xml"
+$DOCEXTRACT_TO_XML_PY $PARAMS > "$OUT_DIR/champlain_docs.xml"
diff --git a/tools/gen_scripts/champlain_generate_enums.sh b/tools/gen_scripts/champlain_generate_enums.sh
index bab8988..4d6b17d 100755
--- a/tools/gen_scripts/champlain_generate_enums.sh
+++ b/tools/gen_scripts/champlain_generate_enums.sh
@@ -10,7 +10,7 @@ if [ -z "$JHBUILD_SOURCES" ]; then
 fi
 
 ROOT_DIR="$(dirname "$0")/../.."
-OUT_DIR="$ROOT_DIR/libchamplain/src"
+OUT_DIR="$ROOT_DIR/champlain/src"
 
 ENUM_PL="$JHBUILD_SOURCES/glibmm/tools/enum.pl"
-$ENUM_PL "$JHBUILD_SOURCES"/libchamplain/champlain/*.h > "$OUT_DIR"/libchamplain_enums.defs
+$ENUM_PL "$JHBUILD_SOURCES"/champlain/champlain/*.h > "$OUT_DIR"/champlain_enums.defs
diff --git a/tools/gen_scripts/champlain_generate_methods.sh b/tools/gen_scripts/champlain_generate_methods.sh
index 9da46c7..ac79bf5 100755
--- a/tools/gen_scripts/champlain_generate_methods.sh
+++ b/tools/gen_scripts/champlain_generate_methods.sh
@@ -10,7 +10,7 @@ if [ -z "$JHBUILD_SOURCES" ]; then
 fi
 
 ROOT_DIR="$(dirname "$0")/../.."
-OUT_DIR="$ROOT_DIR/libchamplain/src"
+OUT_DIR="$ROOT_DIR/champlain/src"
 
 H2DEF_PY="$JHBUILD_SOURCES/glibmm/tools/defs_gen/h2def.py"
-$H2DEF_PY "$JHBUILD_SOURCES"/libchamplain/champlain/*.h > "$OUT_DIR"/libchamplain_methods.defs
+$H2DEF_PY "$JHBUILD_SOURCES"/champlain/champlain/*.h > "$OUT_DIR"/champlain_methods.defs


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/tools/gen_scripts/champlain_generate_extra_defs.sh 
b/tools/gen_scripts/champlain_generate_extra_defs.sh
index f6c8372..ded203d 100755
--- a/tools/gen_scripts/champlain_generate_extra_defs.sh
+++ b/tools/gen_scripts/champlain_generate_extra_defs.sh
@@ -1,26 +1,26 @@
 #!/bin/bash
 
 # The script assumes that it resides in the tools/gen_scripts directory
 # and the defs files will be placed in libchamplain/src.
 # It shall be executed from the tools/gen_scripts directory.
 
 # To update the libchamplain_signals.defs file:
 # 1. ./champlain_generate_extra_defs.sh
-#    Generates libchamplain/src/libchamplain_signals.defs.orig and 
libchamplain/src/libchamplain_signals.defs.
+#    Generates champlain/src/champlain_signals.defs.orig and champlain/src/champlain_signals.defs.
 #    If any hunks from the patch file fail to apply, apply them manually to the
 #    libchamplain_signals.defs file, if required.
 # 2. Optional: Remove libchamplain/src/libchamplain_signals.defs.orig.
 
 # To update the libchamplain_signals.defs file and the patch file:
 # 1. Like step 1 when updating only the libchamplain_signals.defs file.
 # 2. Apply new patches manually to the libchamplain_signals.defs file.
 # 3. ./champlain_generate_extra_defs.sh --make-patch
 # 4. Like step 2 when updating only the libchamplain_signals.defs file.
 
 ROOT_DIR="$(dirname "$0")/../.."
 GEN_DIR="$ROOT_DIR/tools/extradefs"
-OUT_DIR="$ROOT_DIR/libchamplain/src"
-OUT_DEFS_FILE="$OUT_DIR"/libchamplain_signals.defs
+OUT_DIR="$ROOT_DIR/champlain/src"
+OUT_DEFS_FILE="$OUT_DIR"/champlain_signals.defs
 
 if [ $# -eq 0 ]
 then
@@ -1,26 +1,26 @@
 
 # The script assumes that it resides in the tools/gen_scripts directory
-# and the defs files will be placed in libchamplain/src.
+# and the defs files will be placed in champlain/src.
 # It shall be executed from the tools/gen_scripts directory.
 
@@ -1,26 +1,26 @@
 # It shall be executed from the tools/gen_scripts directory.
 
-# To update the libchamplain_signals.defs file:
+# To update the champlain_signals.defs file:
 # 1. ./champlain_generate_extra_defs.sh
@@ -1,26 +1,26 @@
 #    If any hunks from the patch file fail to apply, apply them manually to the
-#    libchamplain_signals.defs file, if required.
-# 2. Optional: Remove libchamplain/src/libchamplain_signals.defs.orig.
+#    champlain_signals.defs file, if required.
+# 2. Optional: Remove champlain/src/champlain_signals.defs.orig.
 
@@ -1,26 +1,26 @@
 
-# To update the libchamplain_signals.defs file and the patch file:
-# 1. Like step 1 when updating only the libchamplain_signals.defs file.
-# 2. Apply new patches manually to the libchamplain_signals.defs file.
+# To update the champlain_signals.defs file and the patch file:
+# 1. Like step 1 when updating only the champlain_signals.defs file.
+# 2. Apply new patches manually to the champlain_signals.defs file.
 # 3. ./champlain_generate_extra_defs.sh --make-patch
@@ -1,26 +1,26 @@
 # 3. ./champlain_generate_extra_defs.sh --make-patch
-# 4. Like step 2 when updating only the libchamplain_signals.defs file.
+# 4. Like step 2 when updating only the champlain_signals.defs file.
 
 ROOT_DIR="$(dirname "$0")/../.."